pub struct AsyncSidecar { /* private fields */ }Expand description
Background thread for non-blocking dirty flag I/O
Implementations
Sourceimpl AsyncSidecar
impl AsyncSidecar
Sourcepub async fn set_dirty(&self, path: PathBuf) -> Result<()>
pub async fn set_dirty(&self, path: PathBuf) -> Result<()>
Set the dirty flag asynchronously and wait for confirmation
Sourcepub fn set_dirty_blind(&self, path: PathBuf)
pub fn set_dirty_blind(&self, path: PathBuf)
Set the dirty flag without waiting for completion (fire-and-forget)
Sourcepub fn clear_dirty(&self, path: PathBuf)
pub fn clear_dirty(&self, path: PathBuf)
Clear the dirty flag asynchronously
Sourcepub fn clear_dirty_on_skip(&self, target_path: PathBuf)
pub fn clear_dirty_on_skip(&self, target_path: PathBuf)
Clear the dirty flag when a file is skipped (already in sync)